isReady property
bool
get
isReady
Returns true if the scanner is ready to accept a scan trigger.
Implementation
bool get isReady => this == ScannerStatus.ready;
Returns true if the scanner is ready to accept a scan trigger.
bool get isReady => this == ScannerStatus.ready;