ZebraScanner class

Main class for Zebra Scanner Plugin

Provides methods to:

  • Initialize the scanner
  • Start/Stop scanning
  • Listen to scan results

Constructors

ZebraScanner()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentStatus ScannerStatus
Get current scanner status
no setter
isInitialized bool
Check if scanner is initialized
no setter
scanResultStream Stream<ScanResult>
Stream of scan results
no setter
statusStream Stream<ScannerStatus>
Stream of scanner status changes
no setter

Static Methods

dispose() → void
Dispose resources and clean up
initialize() Future<bool>
Initialize the Zebra Scanner
startScan() Future<bool>
Start scanning for barcodes
stopScan() Future<bool>
Stop scanning