ScannerStatus enum

Enum representing the scanner status

Inheritance
Available extensions

Values

uninitialized → const ScannerStatus

Scanner is not initialized

ready → const ScannerStatus

Scanner is ready to scan

scanning → const ScannerStatus

Scanner is currently scanning

error → const ScannerStatus

Scanner encountered an error

disabled → const ScannerStatus

Scanner is disabled

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isInitialized bool

Available on ScannerStatus, provided by the ScannerStatusExtension extension

Returns true if the scanner has been successfully initialized.
no setter
isReady bool

Available on ScannerStatus, provided by the ScannerStatusExtension extension

Returns true if the scanner is ready to accept a scan trigger.
no setter
isScanning bool

Available on ScannerStatus, provided by the ScannerStatusExtension extension

Returns true if the scanner is actively scanning.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusLabel String

Available on ScannerStatus, provided by the ScannerStatusExtension extension

Human-readable label for this status.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ScannerStatus>
A constant List of the values in this enum, in order of their declaration.