ZebraScannerService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
dispose(
) → void - Dispose resources
-
initialize(
{dynamic onScanResult(String)?}) → void - Initialize the service and set up scan result callback
-
initializeScanner(
) → Future< String> - Initialize the DataWedge scanner
-
startScanning(
) → Future< String> - Start barcode scanning (soft trigger)
-
stopScanning(
) → Future< String> - Stop barcode scanning